@@ -2,6 +2,7 @@ from django import template
 from django.utils.safestring import mark_safe
 from django.template.loader import get_template
 from base64 import b64encode as encode
+from django.conf import settings
 
 
 register = template.Library()
@@ -22,12 +23,13 @@ class SkelNode(template.Node):
         request = context['request']
 
         # render facet
-        renderer = request.html_renderer
-        facet = renderer.render(path, t.render(context))
-
-        #api = request.studiogdo_api
-        #response = api.post_facet(encode(path), t.render(context), 'dom5')
-        #facet = unicode(response.content, 'utf-8')
+        if settings.STUDIOGDO_FACET == "django":
+            renderer = request.html_renderer
+            facet = renderer.render(path, t.render(context))
+        elif settings.STUDIOGDO_FACET == "java":
+            api = request.studiogdo_api
+            response = api.post_facet(encode(path), t.render(context), 'dom5')
+            facet = unicode(response.content, 'utf-8')
 
         # set trace
         if context['studiogdo_debug']:
